@@ -77,7 +77,11 @@ I<WG_NO_COLOR>: If defined, the show command does not prettify the output with c
 
 =back
 
-=head1 SYNOPSIS
+=head1 SYNOPSIS (Parser)
+
+Please refer to the respective modules L<Wireguard::WGmeta::Wrapper::Config> and L<Wireguard::WGmeta::Wrapper::Show>
+
+=head1 SYNOPSIS (CLI)
 
 Intended to use as command wrapper for the C<wg show> and C<wg set> commands. Support for C<wg-quick> is enabled by default.
 
@@ -131,5 +135,36 @@ I<wgXX.conf> file (Metadata is prefixed with I<#+>):
 	AllowedIPs = 0.0.0.0/0
 	Endpoint = wg.example.com
 
+=head1 AUTHORS
+
+S<Tobias Bossert E<lt>tobib at cpan.orgE<gt>>
+
+=head1 COPYRIGHT AND LICENSE
+
+MIT License
+
+Copyright (c) 2020 Tobias Bossert
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all
+copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+SOFTWARE.
+
 =cut
+
+package Wireguard::WGmeta;
+
 1;
\ No newline at end of file
